obtainArea: obtainArea: Function to obtain a boundry for a specified...

View source: R/obtainArea.R

obtainAreaR Documentation

obtainArea: Function to obtain a boundry for a specified country.

Description

Function to obtain a sf boundary object around a specified country.

Usage

obtainArea(names, projection, ...)

Arguments

names

A vector of names of countries used in the analysis.

projection

Coordinate reference system used.

...

Additional arguments passed to gisco_get_countries.

Value

An sf object of the boundary of the specified country.


intSDM documentation built on Sept. 9, 2025, 5:59 p.m.