obtainCovariate: obtainCovariate: Function to obtain a covariate later for a...

View source: R/obtainCovariate.R

obtainCovariateR Documentation

obtainCovariate: Function to obtain a covariate later for a specified country.

Description

Function to obtain covariate layers from WorldClim or ESA around a specified area.

Usage

obtainCovariate(covariates, type, res, projection, path)

Arguments

covariates

A vector of covariate names to obtain.

type

Type of covariate to include. Must be one of: 'worldclim' or 'landcover'.

res

Resolution of the worldclim variable. Valid options are: 10, 5, 2.5 or 0.5 (minutes of a degree).

projection

Coordinate reference system to use in analysis.

path

The path where the covariate will be saved.

Value

A spatialRaster object of the covariates across the specified area.


intSDM documentation built on Sept. 9, 2025, 5:59 p.m.