| obtainGBIF | R Documentation |
Function used to obtain species observations from GBIF.
obtainGBIF(query, geometry, projection, datasettype, filterDistance, ...)
query |
The scientific name of the species for which observations need to be obtained. |
geometry |
An |
projection |
The coordinate reference system used for the observations and geometry. |
datasettype |
The type of dataset that is obtained from GBIF. Can be one of: |
filterDistance |
Remove all points x km away from the boundary polygon. |
... |
Additional arguments to pass to occ_download. |
An sf object containing the locations and other relevant information of the species obtained from GBIF.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.