View source: R/obtainRichness.R
| obtainRichness | R Documentation |
obtainRichness: Function to obtain richness estimates from a fitISDM object.This function is used to obtain richness estimates for a multi-species ISDM.
obtainRichness(
modelObject,
predictionData,
predictionIntercept,
sampleSize = 1,
inclProb = TRUE
)
modelObject |
A |
predictionData |
An |
predictionIntercept |
The name of the prediction dataset to use in the model. |
sampleSize |
The size of the sampling area for the prediction intercept dataset. Defaults to |
inclProb |
Include the individual probabilities for each species. Defaults to |
An sf data.frame object of richness at each sampling location.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.