| obtainArea | R Documentation |
Function to obtain a sf boundary object around a specified country.
obtainArea(names, projection, ...)
names |
A vector of names of countries used in the analysis. |
projection |
Coordinate reference system used. |
... |
Additional arguments passed to gisco_get_countries. |
An sf object of the boundary of the specified country.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.